@@ -13,6 +13,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->timeoutBox->setText(QSettings().value("main/timeout").toString());
     ui->autohideBox->setText(QSettings().value("main/autohide-timeout").toString());
     ui->showMetadataCheckbox->setChecked(QSettings().value("main/showMetadata").toBool());
+    ui->vibrateCheckbox->setChecked(QSettings().value("main/vibrate").toBool());
 }
 
 SettingsDialog::~SettingsDialog()
@@ -25,5 +26,6 @@ void SettingsDialog::accept()
     QSettings().setValue("main/timeout", ui->timeoutBox->text().toInt());
     QSettings().setValue("main/autohide-timeout", ui->autohideBox->text().toInt());
     QSettings().setValue("main/showMetadata", ui->showMetadataCheckbox->isChecked());
+    QSettings().setValue("main/vibrate", ui->vibrateCheckbox->isChecked());
     this->close();
 }
